==> tur-trial_1.1.tar.gz: tur-trial.sh <==
#!/bin/bash
##################################################################
# Turranius User Trial 1.1                                       #
# This script, together with tur-trial.tcl, can be used to check #
# how your users is doing in either a weekly or montly trial     #
# using !passed <user> from irc.                                 #
# It supports up to 9 stat sections. If it finds more then one   #
# it will simply add them all up.                                #
#                                                                #
# Trial users should be in group TRiAL, and since the trials     #
# always starts when the reset binary reset the stats, you can   #
# also put users in a TRiAL-2 group. (so you can add them to     #
# site before the trial begins). TRiAL-2 = trial next week.      #
# Remember to remove them from TRiAL-2 when you add them to      #
# TRiAL.                                                         #
#                                                                #
# This script will not delete any users. Thats up to you.        #
# Get the triallist script from http://www.grandis.nu/glftpd/    #
# to make it log the results after each trial period.            #
#                                                                #
# Installation:                                                  #
# You need some standard binaries, like grep, cat, expr & tr.    #
#                                                                #
# Put tur-trial.sh in glftpd's bin dir, and                      #
# tur-trial.tcl in your bots scripts dir. Load the tcl in        #
# your bots conf file. Rehash the bot.                           #
#                                                                #
# Make sure tur-trial.sh is executable by the user               #
# who runs the bot.                                              #
#                                                                #
# Set up the parameters below and try to run tur-trial.sh        #
# from shell. If it works from shell, it should work from        #
# the bot.                                                       #
#                                                                #
# If you wish to change the outputs, you can use $BOLD to start  #
# and stop the text from being displayed in bold.                #
#                                                                #
# It can also be run from the ftp if you dont want/have          #
# a bot. Just remember to remove /glftpd from the path           #
# and set BOLD to =""                                            #
##################################################################
# Changelog:                                                     #
# 1.1 : Added support for up to 9 stat sections.                 #
# 1.0 : Initial release.                                         #
##################################################################
# Settings:

USERSLOCATION=/glftpd/ftp-data/users     # Userfiles location.
LIMIT="1500"                             # MB to pass the trial.
DURATION="W"                             # W = weekly. M = monthly trial.
BOLD=""                                # Dont change this one :)
SITENAME="$BOLD-xXx-$BOLD"               # Name of site (replace the xXx).
SHOWLIMIT="TRUE"                         # Show the limit in output? TRUE/FALSE
EXCLUDE="default.user glftpd"            # These users cant be checked. Space delimited.
EXCLUDEDTEXT="$1 cant be checked"        # Text to show incase user is excluded. 
                                         # Leave empty to not say anything.

###############################################################################
# No changes should be needed under here, unless you want to change some text #
###############################################################################

## If no argument is given after trigger:
if [ "$1" = "" ]; then
  echo "$SITENAME Specify a user to check too."
  exit 0
fi

## Check if the user really exists.
if [ -e $USERSLOCATION/$1 ]; then
  OK=OK
else
  echo "$SITENAME User $BOLD$1$BOLD does not exists on $SITENAME"
  exit 0
fi

## Is the user excluded?
EXCLUDED="$( echo "$EXCLUDE" | grep -w $1 )"
if [ "$EXCLUDED" != "" ]; then
  if [ "$EXCLUDEDTEXT" = "" ]; then
    exit 0
  else
    echo "$SITENAME $EXCLUDEDTEXT"
    exit 0
  fi
fi  

## Do we want weekly or monthly trials?
case $DURATION in
 W) 
   DUR="WKUP"
   DURNAME="week"
   ;;
 M)
   DUR="MONTHUP"
   DURNAME="month"
   ;;
 *)
   echo "Duration not set right. Either W or M"
   exit 0
   ;;
esac

## Check if the group is TRiAL on the user specified.
GROUP="$(cat $USERSLOCATION/$1 | grep "GROUP TRiAL" | egrep -iv "TRiAL-2")"
  if [ "$GROUP" != "" ]; then
    TEXT="is up for trial"
    WHEN="NOW"
  fi

## If he wasnt, check if its TRiAL-2 for next trial period.
if [ "$WHEN" = "" ]; then
  GROUP="$(cat $USERSLOCATION/$1 | grep "GROUP TRiAL-2")"
  if [ "$GROUP" != "" ]; then
    TEXT="is up for trial next $DURNAME"
    WHEN="NEXT"
  else
    TEXT="is not on trial"
    WHEN="NOT"
  fi
fi

## How much did the user upload this period? 
UP="$( cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $3}')"
if [ "$UP" = "" ]; then
  UP="0"
fi

## Check for other stat sections.
UP2="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $6}')"
if [ "$UP2" != "" ]; then
  UP3="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $9}')"
  if [ "$UP3" != "" ]; then
    UP4="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $12}')"
    if [ "$UP4" != "" ]; then
      UP5="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $15}')"
      if [ "$UP5" != "" ]; then
        UP6="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $18}')"
        if [ "$UP6" != "" ]; then
          UP7="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $21}')"
          if [ "$UP7" != "" ]; then
            UP8="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $24}')"
            if [ "$UP8" != "" ]; then
              UP9="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $27}')"
              if [ "$UP9" != "" ]; then
                UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" \+ "$UP8" \+ "$UP9" )"
              else
                UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" \+ "$UP8" )"
              fi
            else
              UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" )"
            fi
          else
            UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" )"
          fi
        else
          UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" )"
        fi
      else
        UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" )"
      fi
    else
      UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" )"
    fi
  else
    UP="$( expr "$UP" \+ "$UP2" )"
  fi
fi

## Split the uploaded number with 1024 to get MB.
UP="$( expr $UP \/ 1024 )"

## Is the user over the limit?
if [ "$UP" -gt "$LIMIT" ]; then
  PASSED="YES"
else
  PASSED="NO"
fi

## Calculate how much under or over the limit the user is.
RATIO="$( expr $UP \- $LIMIT )"

## If the number is negative, remove the - 
RATIO="$( echo $RATIO | tr -d "-")"

## Do we want to show the limit in output?
if [ "$SHOWLIMIT" = "TRUE" ]; then
  SHOWL=" ($LIMIT MB/$DURNAME)"
else
  SHOWL=""
fi

## Say what we want to say, depending on if the user passed the limit or not, and if hes on trial.
case $PASSED in
  YES)
    if [ "$WHEN" = "NOT" ]; then
      echo "$SITENAME $BOLD$1$BOLD $TEXT. If $1 had been, the limit$SHOWL would have been passed with $BOLD$RATIO MB$BOLD to spare."
      exit 0
    else
      if [ "$WHEN" = "NEXT" ]; then
        echo "$SITENAME $BOLD$1$BOLD $TEXT. Had it been this $DURNAME, $1 would have passed the limit$SHOWL with $BOLD$RATIO$BOLD to spare."
        exit 0
      else
        echo "$SITENAME $BOLD$1$BOLD $TEXT. $1 have passed the limit$SHOWL with $BOLD$RATIO$BOLD to spare."
        exit 0
      fi
    fi
    ;;
  NO)
    if [ "$WHEN" = "NOT" ]; then
      echo "$SITENAME $BOLD$1$BOLD $TEXT. If $1 was on trial, $1 would be missing $BOLD$RATIO MB$BOLD to pass$SHOWL."
      exit 0
    else
      if [ "$WHEN" = "NEXT" ]; then
        echo "$SITENAME $BOLD$1$BOLD $TEXT. Had it been this $DURNAME, $1 would be missing $BOLD$RATIO MB$BOLD to pass$SHOWL."
        exit 0
      else
        echo "$SITENAME $BOLD$1$BOLD $TEXT. $1 is missing $BOLD$RATIO MB$BOLD to pass$SHOWL."
        exit 0
      fi
    fi
    ;;
  *)
    echo "Error in script. User neither passed or failed trial."
    exit 1
    ;;
esac

exit 0

==> tur-trial_1.2.tar.gz: tur-trial.sh <==
#!/bin/bash
##################################################################
# Turranius User Trial 1.2                                       #
# This script, together with tur-trial.tcl, can be used to check #
# how your users is doing in either a weekly or montly trial     #
# using !passed <user> from irc.                                 #
# It supports up to 9 stat sections. If it finds more then one   #
# it will simply add them all up.                                #
#                                                                #
# Trial users should be in group TRiAL, and since the trials     #
# always starts when the reset binary reset the stats, you can   #
# also put users in a TRiAL-2 group. (so you can add them to     #
# site before the trial begins). TRiAL-2 = trial next week.      #
# Remember to remove them from TRiAL-2 when you add them to      #
# TRiAL.                                                         #
#                                                                #
# This script will not delete any users. Thats up to you.        #
# Get the triallist script from http://www.grandis.nu/glftpd/    #
# to make it log the results after each trial period.            #
#                                                                #
# Installation:                                                  #
# You need some standard binaries, like grep, cat, expr & tr.    #
#                                                                #
# Put tur-trial.sh in glftpd's bin dir, and                      #
# tur-trial.tcl in your bots scripts dir. Load the tcl in        #
# your bots conf file. Rehash the bot.                           #
#                                                                #
# Make sure tur-trial.sh is executable by the user               #
# who runs the bot.                                              #
#                                                                #
# Set up the parameters below and try to run tur-trial.sh        #
# from shell. If it works from shell, it should work from        #
# the bot.                                                       #
#                                                                #
# If you wish to change the outputs, you can use $BOLD to start  #
# and stop the text from being displayed in bold.                #
#                                                                #
# It can also be run from the ftp if you dont want/have          #
# a bot. Just remember to remove /glftpd from the path           #
# and set BOLD to =""                                            #
##################################################################
# Changelog:                                                     #
# 1.2 : Will now show how many days/hours left on trial, as well #
#       as how many megs per day the user has to upload to pass. #
#       Days will break down to Hours and Minutes as the end of  #
#       the trial gets closer.                                   #
# 1.1 : Added support for up to 9 stat sections.                 #
# 1.0 : Initial release.                                         #
##################################################################
# Settings:

USERSLOCATION=/glftpd/ftp-data/users     # Userfiles location.
LIMIT="1500"                             # MB to pass the trial.
DURATION="W"                             # W = weekly. M = monthly trial.
BOLD=""                                # Dont change this one :)
SITENAME="$BOLD-xXx-$BOLD"               # Name of site (replace the xXx).
SHOWLIMIT="TRUE"                         # Show the limit in output? TRUE/FALSE
EXCLUDE="default.user"                   # These users cant be checked. Space delimited.
EXCLUDEDTEXT="$1 cant be checked"        # Text to show incase user is excluded. 
                                         # Leave empty to not say anything.


###############################################################################
# No changes should be needed under here, unless you want to change some text #
###############################################################################

## If no argument is given after trigger:
if [ "$1" = "" ]; then
  echo "$SITENAME Specify a user to check too."
  exit 0
fi

## Check if the user really exists.
if [ -e $USERSLOCATION/$1 ]; then
  OK=OK
else
  echo "$SITENAME User $BOLD$1$BOLD does not exists on $SITENAME"
  exit 0
fi

## Is the user excluded?
EXCLUDED="$( echo "$EXCLUDE" | grep -w $1 )"
if [ "$EXCLUDED" != "" ]; then
  if [ "$EXCLUDEDTEXT" = "" ]; then
    exit 0
  else
    echo "$SITENAME $EXCLUDEDTEXT"
    exit 0
  fi
fi  

## Do we want weekly or monthly trials?
case $DURATION in
 W) 
   DUR="WKUP"
   DURNAME="week"
   ;;
 M)
   DUR="MONTHUP"
   DURNAME="month"
   ;;
 *)
   echo "Duration not set right. Either W or M"
   exit 0
   ;;
esac

## Check if the group is TRiAL on the user specified.
GROUP="$(cat $USERSLOCATION/$1 | grep "GROUP TRiAL" | egrep -iv "TRiAL-2")"
  if [ "$GROUP" != "" ]; then
    TEXT="is up for trial"
    WHEN="NOW"
  fi

## If he wasnt, check if its TRiAL-2 for next trial period.
if [ "$WHEN" = "" ]; then
  GROUP="$(cat $USERSLOCATION/$1 | grep "GROUP TRiAL-2")"
  if [ "$GROUP" != "" ]; then
    TEXT="is up for trial next $DURNAME"
    WHEN="NEXT"
  else
    TEXT="is not on trial"
    WHEN="NOT"
  fi
fi

## How much did the user upload this period? 
UP="$( cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $3}')"
if [ "$UP" = "" ]; then
  UP="0"
fi

## Check for other stat sections.
UP2="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $6}')"
if [ "$UP2" != "" ]; then
  UP3="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $9}')"
  if [ "$UP3" != "" ]; then
    UP4="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $12}')"
    if [ "$UP4" != "" ]; then
      UP5="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $15}')"
      if [ "$UP5" != "" ]; then
        UP6="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $18}')"
        if [ "$UP6" != "" ]; then
          UP7="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $21}')"
          if [ "$UP7" != "" ]; then
            UP8="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $24}')"
            if [ "$UP8" != "" ]; then
              UP9="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $27}')"
              if [ "$UP9" != "" ]; then
                UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" \+ "$UP8" \+ "$UP9" )"
              else
                UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" \+ "$UP8" )"
              fi
            else
              UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" )"
            fi
          else
            UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" )"
          fi
        else
          UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" )"
        fi
      else
        UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" )"
      fi
    else
      UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" )"
    fi
  else
    UP="$( expr "$UP" \+ "$UP2" )"
  fi
fi

## Split the uploaded number with 1024 to get MB.
UP="$( expr $UP \/ 1024 )"

## Is the user over the limit?
if [ "$UP" -gt "$LIMIT" ]; then
  PASSED="YES"
else
  PASSED="NO"
fi

## Calculate how much under or over the limit the user is.
RATIO="$( expr $UP \- $LIMIT )"

## If the number is negative, remove the - 
RATIO="$( echo $RATIO | tr -d "-")"

if [ "$DURATION" = "M" ]; then
  MONTNOW="$( date +%b )"
  case $MONTHNOW in
    Jan) MONTHTOTAL="31" ;;
    Feb) MONTHTOTAL="28" ;;
    Mar) MONTHTOTAL="31" ;;
    Apr) MONTHTOTAL="30" ;;
    May) MONTHTOTAL="31" ;;
    Jun) MONTHTOTAL="30" ;;
    Jul) MONTHTOTAL="31" ;;
    Aug) MONTHTOTAL="31" ;;
    Sep) MONTHTOTAL="30" ;;
    Oct) MONTHTOTAL="31" ;;
    Nov) MONTHTOTAL="30" ;;
    Dec) MONTHTOTAL="31" ;;
    *) MONTHTOTAL="31" ;;   
  esac

  DAYNOW="$( date +%d )"
  if [ "$MONTHTOTAL" = "$DAYNOW" ]; then
    DURATION="W"
  else
    DAYSLEFT="$( expr $MONTHTOTAL \- $DAYNOW )"
    if [ "$DAYNOW" = "01" ]; then
      DAY="the whole month remaining"
    else
      DAY="$DAYSLEFT days remaining"
    fi
    PERDAY="$( expr $RATIO \/ $DAYSLEFT )"
    PERDAY="which means another $PERDAY MB per day" 
  fi
fi

if [ "$DURATION" = "W" ]; then
  DAYNOW="$( date +%w )"
  case $DAYNOW in
    0) DAY="7 days remaining"
       SPLIT="7" ;;
    1) DAY="6 days remaining"
       SPLIT="6" ;;
    2) DAY="5 days remaining"
       SPLIT="5" ;;
    3) DAY="4 days remaining"
       SPLIT="4" ;;
    4) DAY="3 days remaining"
       SPLIT="3" ;;
    5) DAY="2 days remaining"
       SPLIT="2" ;;
    6) DAY="1 day remaining"
       SPLIT="1" ;;
    *) DAY="Hell if I know what day it is.."
       SPLIT="1" ;;
  esac

  if [ "$SPLIT" = "1" ]; then
    HOURNOW="$( date +%k )"
    HLEFT="$( expr 24 \- $HOURNOW )"
    if [ "$HLEFT" = "1" ]; then
      MINUTENOW="$( date +%m )"
      MINLEFT="$( expr 60 \- $MINUTENOW )"
      if [ "$MINLEFT" = "1" ]; then
        DAY="$MINLEFT minute left"
      else
        DAY="$MINLEFT minutes left"
      fi
      PERDAY="$( expr $RATIO \/ $MINLEFT )"
      PERDAY="which means another $PERDAY MB per minute" 
    else
      DAY="$HLEFT hours left"
      PERDAY="$( expr $RATIO \/ $HLEFT )"
      PERDAY="which means another $PERDAY MB per hour" 
    fi
  else
    PERDAY="$( expr $RATIO \/ $SPLIT )"
    PERDAY="which means another $PERDAY MB per day" 
  fi
fi


## Do we want to show the limit in output?
if [ "$SHOWLIMIT" = "TRUE" ]; then
  SHOWL=" ($LIMIT MB/$DURNAME)"
else
  SHOWL=""
fi

## Say what we want to say, depending on if the user passed the limit or not, and if hes on trial.
case $PASSED in
  YES)
    if [ "$WHEN" = "NOT" ]; then
      echo "$SITENAME $BOLD$1$BOLD $TEXT. If $1 had been, the limit$SHOWL would have been passed with $BOLD$RATIO MB$BOLD and $DAY."
      exit 0
    else
      if [ "$WHEN" = "NEXT" ]; then
        echo "$SITENAME $BOLD$1$BOLD $TEXT. Had it been this $DURNAME, $1 would have passed the limit$SHOWL with $BOLD$RATIO$BOLD and $DAY."
        exit 0
      else
        echo "$SITENAME $BOLD$1$BOLD $TEXT. $1 have passed the limit$SHOWL with $BOLD$RATIO MB$BOLD and $DAY."
        exit 0
      fi
    fi
    ;;
  NO)
    if [ "$WHEN" = "NOT" ]; then
      echo "$SITENAME $BOLD$1$BOLD $TEXT. If $1 was on trial, $1 would be missing $BOLD$RATIO MB$BOLD with $DAY, $PERDAY$SHOWL."
      exit 0
    else
      if [ "$WHEN" = "NEXT" ]; then
        echo "$SITENAME $BOLD$1$BOLD $TEXT. Had it been this $DURNAME, $1 would be missing $BOLD$RATIO MB$BOLD with $DAY, $PERDAY$SHOWL."
        exit 0
      else
        echo "$SITENAME $BOLD$1$BOLD $TEXT. $1 is missing $BOLD$RATIO MB$BOLD to pass with $DAY, $PERDAY$SHOWL."
        exit 0
      fi
    fi
    ;;
  *)
    echo "Error in script. User neither passed or failed trial."
    exit 1
    ;;
esac

exit 0
